use std::error::Error;

use crossterm::event::{self, KeyCode};

use crate::{
    state::{ApplicationState, Task},
    utility::Op,
};

/// Handle all key events
pub fn event_key_handler(app: &mut ApplicationState) -> Result<(), Box<dyn Error>> {
    if event::poll(std::time::Duration::from_millis(100))? {
        if let event::Event::Key(key_event) = event::read()? {
            match key_event.code {
                // Escape to exit
                KeyCode::Esc => app.should_quit = true,
                KeyCode::Char('a') => app.insert_task(app.selected_col, Task::new_test_task()),
                KeyCode::Char('h') => app.update_selected_column(&Op::Decrement),
                KeyCode::Char('l') => app.update_selected_column(&Op::Increment),
                KeyCode::Char('k') => app.update_selected_item(&Op::Decrement),
                KeyCode::Char('j') => app.update_selected_item(&Op::Increment),
                KeyCode::Char('H') => {
                    app.move_task(app.selected_col, app.selected_item, &Op::Decrement, false)
                }
                KeyCode::Char('L') => {
                    app.move_task(app.selected_col, app.selected_item, &Op::Increment, false)
                }
                KeyCode::Char('K') => {
                    app.move_task(app.selected_col, app.selected_item, &Op::Decrement, true)
                }
                KeyCode::Char('J') => {
                    app.move_task(app.selected_col, app.selected_item, &Op::Increment, true)
                }
                // Resize the window (event handling is automatic with ratatui)
                _ => {}
            }
        }
    };
    Ok(())
}
